Skip to contents

This function retrieves the names and versions of all currently loaded R packages. It returns a data frame with the package names in the first column and their respective versions in the second column.

Usage

loaded_packages_version()

Value

A data frame with two columns:

package

The name of the loaded package.

version

The version of the loaded package.

Examples

# Get the list of loaded packages with versions
loaded_packages_version()
#>         package    version
#> 1   BayesFactor 0.9.12.4.7
#> 2          MASS     7.3.60
#> 3        Matrix      1.6.5
#> 4  MatrixModels      0.5.4
#> 5            R6      2.6.1
#> 6  RColorBrewer      1.1.3
#> 7          Rcpp     1.0.11
#> 8            S7      0.2.1
#> 9          base      4.3.2
#> 10   bayestestR     0.17.0
#> 11        bslib      0.8.0
#> 12       cachem      1.1.0
#> 13          cli      3.6.2
#> 14         coda   0.19.4.1
#> 15     compiler      4.3.2
#> 16         curl      6.2.1
#> 17     datasets      4.3.2
#> 18   datawizard      1.3.0
#> 19         desc      1.4.3
#> 20     devtools      2.4.5
#> 21       digest     0.6.33
#> 22      downlit      0.4.4
#> 23        dplyr      1.1.4
#> 24   effectsize      1.0.1
#> 25     ellipsis      0.3.2
#> 26     evaluate      1.0.3
#> 27        fansi      1.0.6
#> 28       farver      2.1.2
#> 29      fastmap      1.2.0
#> 30  fontawesome      0.5.2
#> 31           fs      1.6.4
#> 32     generics      0.1.4
#> 33      ggplot2      4.0.1
#> 34         glue      1.6.2
#> 35    grDevices      4.3.2
#> 36     graphics      4.3.2
#> 37         grid      4.3.2
#> 38       gtable      0.3.6
#> 39    htmltools    0.5.8.1
#> 40  htmlwidgets      1.6.4
#> 41       httpuv     1.6.15
#> 42        httr2      1.1.0
#> 43      insight      1.4.4
#> 44    jquerylib      0.1.4
#> 45     jsonlite      1.8.8
#> 46        knitr       1.48
#> 47        later      1.4.1
#> 48      lattice     0.21.9
#> 49    lifecycle      1.0.4
#> 50     magrittr      2.0.3
#> 51      memoise      2.0.1
#> 52      methods      4.3.2
#> 53         mime       0.12
#> 54       miniUI    0.1.1.1
#> 55     mutolabr     1.10.0
#> 56      mvtnorm      1.3.3
#> 57     parallel      4.3.2
#> 58   parameters     0.28.3
#> 59      pbapply      1.7.4
#> 60       pillar     1.11.1
#> 61     pkgbuild      1.4.4
#> 62    pkgconfig      2.0.3
#> 63      pkgdown      2.1.1
#> 64      pkgload      1.4.0
#> 65        ppcor        1.1
#> 66      profvis      0.4.0
#> 67     promises      1.3.2
#> 68        purrr      1.0.2
#> 69     rappdirs      0.3.3
#> 70      remotes      2.5.0
#> 71        rlang      1.1.2
#> 72    rmarkdown       2.27
#> 73   rstudioapi     0.16.0
#> 74         sass      0.4.9
#> 75       scales      1.4.0
#> 76  sessioninfo      1.2.3
#> 77        shiny     1.10.0
#> 78        stats      4.3.2
#> 79      stringi      1.8.3
#> 80      stringr      1.6.0
#> 81       tibble      3.2.1
#> 82        tidyr      1.3.0
#> 83   tidyselect      1.2.1
#> 84        tools      4.3.2
#> 85   urlchecker      1.0.1
#> 86      usethis      3.1.0
#> 87         utf8      1.2.4
#> 88        utils      4.3.2
#> 89        vctrs      0.6.5
#> 90      whisker      0.4.1
#> 91        withr      3.0.2
#> 92         xfun       0.47
#> 93         xml2      1.3.6
#> 94       xtable      1.8.4
#> 95         yaml      2.3.8